@@ -11,7 +11,7 @@ from syntropycli.utils import *
 
 @click.group()
 def apis():
-    """Syntropy Networks cli tool"""
+    """Syntropy Networks Command Line Interface."""
 
 
 @apis.command()
@@ -42,7 +42,7 @@ def login(username, password, api):
     payload = {"user_email": username, "user_password": password, "additionalProp1": {}}
     api = sdk.AuthApi(api)
     try:
-        token = api.local(body=payload)
+        token = api.auth_local_login(body=payload)
         click.echo(token["refresh_token"])
     except ApiException as err:
         click.secho("Login was not successful", err=True, fg="red")
@@ -51,41 +51,38 @@ def login(username, password, api):
 
 
 @apis.command()
-@click.option("--skip", default=0, type=int, help="Skip N providers")
-@click.option("--take", default=128, type=int, help="Take N providers")
+@click.option("--skip", default=0, type=int, help="Skip N providers.")
+@click.option("--take", default=128, type=int, help="Take N providers.")
 @click.option(
     "--json",
     "-j",
     is_flag=True,
     default=False,
-    help="Outputs a JSON instead of a table",
+    help="Outputs a JSON instead of a table.",
 )
-@syntropy_api
-def get_providers(skip, take, json, api):
-    """Retrieve a list of providers."""
-    provider = sdk.ProvidersApi(api)
-    providers = provider.index(skip=skip, take=take)
+@syntropy_platform
+def get_providers(skip, take, json, platform):
+    """Retrieve a list of endpoint providers."""
+    providers = platform.platform_agent_provider_index(skip=skip, take=take)
     fields = [
-        ("ID", "provider_id"),
-        ("Name", "provider_name"),
-        ("Created At", "provider_created_at"),
-        ("Updated At", "provider_updated_at"),
+        ("ID", "agent_provider_id"),
+        ("Name", "agent_provider_name"),
     ]
     print_table(providers, fields, to_json=json)
 
 
 @apis.command()
 @click.option(
-    "--show-secret", "-s", is_flag=True, default=False, help="Shows API secrets"
+    "--show-secret", "-s", is_flag=True, default=False, help="Shows API secrets."
 )
-@click.option("--skip", default=0, type=int, help="Skip N API keys")
-@click.option("--take", default=128, type=int, help="Take N API keys")
+@click.option("--skip", default=0, type=int, help="Skip N API keys.")
+@click.option("--take", default=128, type=int, help="Take N API keys.")
 @click.option(
     "--json",
     "-j",
     is_flag=True,
     default=False,
-    help="Outputs a JSON instead of a table",
+    help="Outputs a JSON instead of a table.",
 )
 @syntropy_platform
 def get_api_keys(show_secret, skip, take, json, platform):
@@ -95,7 +92,7 @@ def get_api_keys(show_secret, skip, take, json, platform):
 
     By default this command will retrieve up to 128 API keys. You can use --take parameter to get more keys.
     """
-    keys = platform.index_api_key(skip=skip, take=take)["data"]
+    keys = platform.platform_api_key_index(skip=skip, take=take)["data"]
 
     fields = [
         ("ID", "api_key_id"),
@@ -119,16 +116,16 @@ def get_api_keys(show_secret, skip, take, json, platform):
     type=click.DateTime(formats=["%Y-%m-%d %H:%M:%S"]),
     default=(datetime.now() + timedelta(days=30)).strftime("%Y-%m-%d %H:%M:%S"),
 )
-@click.option("--suspended", "-s", is_flag=True, help="Create a suspended API key")
+@click.option("--suspended", "-s", is_flag=True, help="Create a suspended API key.")
 @syntropy_platform
 def create_api_key(name, suspended, expires, platform):
-    """Create a API key."""
+    """Create a API key for endpoint agent."""
     body = {
         "api_key_name": name,
         "api_key_is_suspended": suspended,
         "api_key_valid_until": expires,
     }
-    result = platform.create_api_key(body=body)
+    result = platform.platform_api_key_create(body=body)
     click.echo(result["data"]["api_key_id"])
 
 
@@ -157,18 +154,18 @@ def delete_api_key(name, id, yes, platform):
         raise SystemExit(1)
 
     if id is None:
-        keys = platform.index_api_key(filter=f"api_key_name:{name}")["data"]
+        keys = platform.platform_api_key_index(filter=f"api_key_name:{name}")["data"]
         for key in keys:
             if not yes and not confirm_deletion(key["api_key_name"], key["api_key_id"]):
                 continue
 
-            platform.delete_api_key(key["api_key_id"])
+            platform.platform_api_key_destroy(key["api_key_id"])
             click.secho(
                 f"Deleted API key: {key['api_key_name']} (id={key['api_key_id']}).",
                 fg="green",
             )
     else:
-        platform.delete_api_key(id)
+        platform.platform_api_key_destroy(id)
         click.secho(f"Deleted API key: id={id}.", fg="green")
 
 
@@ -177,14 +174,14 @@ def _get_endpoints(
 ):
     filters = []
     if name:
-        filters.append(f"id|name:{name}")
+        filters.append(f"id|name:'{name}'")
     elif id:
         filters.append(f"ids[]:{id}")
     if tag:
         filters.append(f"tags_names[]:{tag}")
     if network:
         filters.append(f"networks_names[]:{network}")
-    agents = platform.index_agents(
+    agents = platform.platform_agent_index(
         filter=",".join(filters) if filters else None, skip=skip, take=take
     )["data"]
 
@@ -197,7 +194,7 @@ def _get_endpoints(
             ]
             if len(filtered_agents) < take:
                 skip += take
-                agents = platform.index_agents(
+                agents = platform.platform_agent_index(
                     filter=",".join(filters) if filters else None, skip=skip, take=take
                 )["data"]
         agents = filtered_agents
@@ -219,7 +216,7 @@ def _get_endpoints(
     if show_services:
         ids = [agent["agent_id"] for agent in agents]
         agents_services = BatchedRequest(
-            platform.get_agent_services_with_subnets,
+            platform.platform_agent_service_index,
             max_payload_size=MAX_QUERY_FIELD_SIZE,
         )(ids)["data"]
         agent_services = defaultdict(list)
@@ -238,32 +235,32 @@ def _get_endpoints(
 
 
 @apis.command()
-@click.option("--name", default=None, type=str, help="Filter endpoints by name")
-@click.option("--id", default=None, type=int, help="Filter endpoints by IDs")
+@click.option("--name", default=None, type=str, help="Filter endpoints by name.")
+@click.option("--id", default=None, type=int, help="Filter endpoints by IDs.")
 @click.option(
-    "--network", default=None, type=str, help="Filter endpoints by network name"
+    "--network", default=None, type=str, help="Filter endpoints by network name."
 )
-@click.option("--tag", default=None, type=str, help="Filter endpoints by tag")
-@click.option("--skip", default=0, type=int, help="Skip N endpoints")
-@click.option("--take", default=42, type=int, help="Take N endpoints")
+@click.option("--tag", default=None, type=str, help="Filter endpoints by tag.")
+@click.option("--skip", default=0, type=int, help="Skip N endpoints.")
+@click.option("--take", default=42, type=int, help="Take N endpoints.")
 @click.option(
     "--show-services",
     is_flag=True,
     default=False,
-    help="Retrieves services that are configured for each endpoint",
+    help="Retrieves services that are configured for each endpoint.",
 )
 @click.option(
-    "--online", is_flag=True, default=False, help="List only online endpoints"
+    "--online", is_flag=True, default=False, help="List only online endpoints."
 )
 @click.option(
-    "--offline", is_flag=True, default=False, help="List only offline endpoints"
+    "--offline", is_flag=True, default=False, help="List only offline endpoints."
 )
 @click.option(
     "--json",
     "-j",
     is_flag=True,
     default=False,
-    help="Outputs a JSON instead of a table",
+    help="Outputs a JSON instead of a table.",
 )
 @syntropy_platform
 def get_endpoints(
@@ -310,7 +307,7 @@ def get_endpoints(
     "-j",
     is_flag=True,
     default=False,
-    help="Outputs a JSON instead of a table",
+    help="Outputs a JSON instead of a table.",
 )
 @click.option(
     "--set-provider",
@@ -359,7 +356,7 @@ def get_endpoints(
     multiple=True,
     help="Remove a tag from the endpoint(won't affect other tags). Supports multiple options.",
 )
-@click.option("--clear-tags", is_flag=True, default=False, help="Removes all tags")
+@click.option("--clear-tags", is_flag=True, default=False, help="Removes all tags.")
 @click.option(
     "--disable-service",
     "-D",
@@ -374,8 +371,8 @@ def get_endpoints(
 @click.option(
     "--enable-all-services", is_flag=True, default=False, help="Enable all services."
 )
-@click.option("--skip", default=0, type=int, help="Skip N endpoints")
-@click.option("--take", default=42, type=int, help="Take N endpoints")
+@click.option("--skip", default=0, type=int, help="Skip N endpoints.")
+@click.option("--take", default=42, type=int, help="Take N endpoints.")
 @syntropy_platform
 def configure_endpoints(
     platform,
@@ -404,14 +401,14 @@ def configure_endpoints(
 
     \b
     then syntropyctl will:
-        1. clear all tags and add tag1 and tag2
-        2. add tag3 and tag4
-        3. remove tag1
+        1. clear all tags and add tag1 and tag2,
+        2. add tag3 and tag4,
+        3. remove tag1.
 
     The same applies to services.
     """
-    agents = platform.index_agents(
-        filter=f"id|name:{endpoint}",
+    agents = platform.platform_agent_index(
+        filter=f"id|name:'{endpoint}'",
     )["data"]
 
     if not agents:
@@ -430,7 +427,7 @@ def configure_endpoints(
         }
         for agent in agents:
             original_tags = agents_tags.get(agent["agent_id"], [])
-            tags = _update_list(original_tags, set_tag, add_tag, remove_tag, clear_tags)
+            tags = update_list(original_tags, set_tag, add_tag, remove_tag, clear_tags)
             payload = {}
             if set_provider and set_provider != agent.get("agent_provider", {}).get(
                 "agent_provider_name"
@@ -441,7 +438,7 @@ def configure_endpoints(
             ) != set(tags):
                 payload["agent_tags"] = tags
             if payload:
-                platform.patch_agents(payload, agent["agent_id"])
+                platform.platform_agent_update(payload, agent["agent_id"])
                 click.secho("Tags and provider configured.", fg="green")
             else:
                 click.secho(
@@ -459,7 +456,7 @@ def configure_endpoints(
         show_services = True
         ids = [agent["agent_id"] for agent in agents]
         agents_services_all = BatchedRequest(
-            platform.get_agent_services_with_subnets,
+            platform.platform_agent_service_index,
             max_payload_size=MAX_QUERY_FIELD_SIZE,
         )(ids)["data"]
         agents_services = defaultdict(list)
@@ -484,7 +481,7 @@ def configure_endpoints(
                     or enable_all_services
                 )
             ]
-            enabled_services = _update_list(
+            enabled_services = update_list(
                 enabled_services,
                 set_service,
                 enable_service,
@@ -513,7 +510,7 @@ def configure_endpoints(
             ]
             if subnets:
                 payload = {"subnetsToUpdate": subnets}
-                platform.update_agent_services_subnets_status(payload)
+                platform.platform_agent_service_subnet_update(payload)
                 click.secho("Service subnets updated.", fg="green")
             else:
                 click.secho("Nothing to do for service configuration.", fg="yellow")
@@ -539,12 +536,12 @@ def configure_endpoints(
     "-j",
     is_flag=True,
     default=False,
-    help="Outputs a JSON instead of a table",
+    help="Outputs a JSON instead of a table.",
 )
 @syntropy_platform
 def get_topology(json, platform):
     """Retrieves networks topology."""
-    topology = platform.topology_networks()["data"]
+    topology = platform.platform_network_topology()["data"]
 
     fields = [
         ("Network name", "network_name"),
@@ -559,23 +556,26 @@ def get_topology(json, platform):
 
 @apis.command()
 @click.option(
-    "--network", default=None, type=str, help="Filter connections by network name or ID"
+    "--network",
+    default=None,
+    type=str,
+    help="Filter connections by network name or ID.",
 )
-@click.option("--id", default=None, type=int, help="Filter endpoints by ID")
-@click.option("--skip", default=0, type=int, help="Skip N connections")
-@click.option("--take", default=42, type=int, help="Take N connections")
+@click.option("--id", default=None, type=int, help="Filter endpoints by ID.")
+@click.option("--skip", default=0, type=int, help="Skip N connections.")
+@click.option("--take", default=42, type=int, help="Take N connections.")
 @click.option(
     "--show-services",
     is_flag=True,
     default=False,
-    help="Retrieves services that are configured for each endpoint",
+    help="Retrieves services that are configured for each endpoint.",
 )
 @click.option(
     "--json",
     "-j",
     is_flag=True,
     default=False,
-    help="Outputs a JSON instead of a table",
+    help="Outputs a JSON instead of a table.",
 )
 @syntropy_platform
 def get_connections(network, id, skip, take, show_services, json, platform):
@@ -598,14 +598,16 @@ def get_connections(network, id, skip, take, show_services, json, platform):
         try:
             filters.append(f"networks[]:{int(network)}")
         except ValueError:
-            networks = platform.index_networks(filter=f"id|name:{network}")["data"]
+            networks = platform.platform_network_index(filter=f"id|name:'{network}'")[
+                "data"
+            ]
             filters.append(
                 f"networks[]:{','.join(str(net['network_id']) for net in networks)}"
             )
 
     if id:
         filters.append(f"id|name:{id}")
-    connections = platform.index_connections(
+    connections = platform.platform_connection_index(
         filter=",".join(filters) if filters else None,
         skip=skip,
         take=take,
@@ -635,7 +637,8 @@ def get_connections(network, id, skip, take, show_services, json, platform):
     if show_services:
         ids = [connection["agent_connection_id"] for connection in connections]
         connections_services = BatchedRequest(
-            platform.get_connection_services, max_payload_size=MAX_QUERY_FIELD_SIZE
+            platform.platform_connection_service_show,
+            max_payload_size=MAX_QUERY_FIELD_SIZE,
         )(ids)["data"]
         connection_services = {
             connection["agent_connection_id"]: connection
@@ -671,7 +674,7 @@ def get_connections(network, id, skip, take, show_services, json, platform):
     "-j",
     is_flag=True,
     default=False,
-    help="Outputs a JSON instead of a table",
+    help="Outputs a JSON instead of a table.",
 )
 @syntropy_platform
 def create_connections(network, agents, use_names, json, platform):
@@ -679,8 +682,8 @@ def create_connections(network, agents, use_names, json, platform):
 
     \b
     Arguments:
-        network - either a network name or ID
-        agents - a list of endpoint ids or names separated by spaces
+        network - either a network name or ID.
+        agents - a list of endpoint ids or names separated by spaces.
 
     In order to use endpoint names instead of ids provide --use-names option.
 
@@ -698,7 +701,7 @@ def create_connections(network, agents, use_names, json, platform):
         7             | 8
     """
 
-    networks = platform.index_networks(filter=f"id|name:{network}")["data"]
+    networks = platform.platform_network_index(filter=f"id|name:'{network}'")["data"]
     if len(networks) != 1:
         click.secho(f"Could not find the network {network}", err=True, fg="red")
         raise SystemExit(1)
@@ -706,7 +709,7 @@ def create_connections(network, agents, use_names, json, platform):
     network = networks[0]["network_id"]
     network_type = networks[0]["network_type"]
     if use_names:
-        all_agents = platform.index_agents(take=TAKE_MAX_ITEMS_PER_CALL)["data"]
+        all_agents = platform.platform_agent_index(take=TAKE_MAX_ITEMS_PER_CALL)["data"]
         agents = find_by_name(all_agents, agents, "agent")
         if any(i is None for i in agents):
             raise SystemExit(1)
@@ -728,7 +731,7 @@ def create_connections(network, agents, use_names, json, platform):
         "agent_ids": agents,
         "network_update_by": sdk.NetworkGenesisType.SDK,
     }
-    connections = platform.create_connections(body=body)["data"]
+    connections = platform.platform_connection_create(body=body)["data"]
 
     fields = [
         ("Connection ID", "agent_connection_id"),
@@ -746,22 +749,22 @@ def create_connections(network, agents, use_names, json, platform):
 @syntropy_platform
 def delete_connection(id, platform):
     """Delete a connection."""
-    platform.delete_connection(id)
+    platform.platform_connection_destroy(id)
 
 
 @apis.command()
-@click.option("--network", default=None, type=str, help="Filter networks by name/ID")
+@click.option("--network", default=None, type=str, help="Filter networks by name/ID.")
 @click.option(
-    "--show-secret", "-s", is_flag=True, default=False, help="Shows Network secrets"
+    "--show-secret", "-s", is_flag=True, default=False, help="Shows Network secrets."
 )
-@click.option("--skip", default=0, type=int, help="Skip N networks")
-@click.option("--take", default=42, type=int, help="Take N networks")
+@click.option("--skip", default=0, type=int, help="Skip N networks.")
+@click.option("--take", default=42, type=int, help="Take N networks.")
 @click.option(
     "--json",
     "-j",
     is_flag=True,
     default=False,
-    help="Outputs a JSON instead of a table",
+    help="Outputs a JSON instead of a table.",
 )
 @syntropy_platform
 def get_networks(network, show_secret, skip, take, json, platform):
@@ -769,8 +772,8 @@ def get_networks(network, show_secret, skip, take, json, platform):
 
     By default this command will retrieve up to 42 networks. You can use --take parameter to get more networks.
     """
-    networks = platform.index_networks(
-        filter=f"id|name:{network}" if network else None,
+    networks = platform.platform_network_index(
+        filter=f"id|name:'{network}'" if network else None,
         skip=skip,
         take=take,
     )["data"]
@@ -867,7 +870,7 @@ def create_network(
             "network_type": topology,
         },
     }
-    result = platform.create_network(body=body)
+    result = platform.platform_network_create(body=body)
     click.echo(result["data"]["network_id"])
 
 
@@ -891,14 +894,14 @@ def create_network(
     default=False,
     help="Use endpoint names instead of ids. Will not work with name duplicates.",
 )
-@click.option("--skip", default=0, type=int, help="Skip N networks")
-@click.option("--take", default=42, type=int, help="Take N networks")
+@click.option("--skip", default=0, type=int, help="Skip N networks.")
+@click.option("--take", default=42, type=int, help="Take N networks.")
 @click.option(
     "--json",
     "-j",
     is_flag=True,
     default=False,
-    help="Outputs a JSON instead of a table",
+    help="Outputs a JSON instead of a table.",
 )
 @syntropy_platform
 def manage_network_endpoints(
@@ -916,8 +919,8 @@ def manage_network_endpoints(
     You can check what networks match by running manage-network-endpoints command without any -r or -a options.
     This will also print already existing endpoints for each network.
     """
-    networks = platform.index_networks(
-        filter=f"id|name:{network}" if network else None,
+    networks = platform.platform_network_index(
+        filter=f"id|name:'{network}'" if network else None,
         skip=skip,
         take=take,
     )["data"]
@@ -932,8 +935,8 @@ def manage_network_endpoints(
     resolved_agents = [
         [
             agent["agent_id"]
-            for agent in WithRetry(platform.index_agents)(
-                filter=f"name:{endpoint}" if use_names else f"ids[]:{endpoint}",
+            for agent in WithRetry(platform.platform_agent_index)(
+                filter=f"name:'{endpoint}'" if use_names else f"ids[]:{endpoint}",
                 load_relations=False,
             )["data"]
         ]
@@ -953,7 +956,7 @@ def manage_network_endpoints(
         add_agents += agent
 
     networks_info = [
-        platform.get_network_info(net["network_id"])["data"] for net in networks
+        platform.platform_network_info(net["network_id"])["data"] for net in networks
     ]
 
     if remove_endpoint:
@@ -967,7 +970,10 @@ def manage_network_endpoints(
                 or (agent["agent"]["agent_name"] in remove_endpoint and use_names)
             ]
             if agents:
-                platform.remove_network_agents(agents, network["network"]["network_id"])
+                for agent in agents:
+                    platform.platform_network_agent_destroy(
+                        network["network"]["network_id"], agent
+                    )
                 click.secho(
                     f"Removed {len(agents)} endpoints from network {network['network']['network_name']}.",
                     fg="yellow",
@@ -986,7 +992,7 @@ def manage_network_endpoints(
                     }
                     for agent in agents
                 ]
-                platform.create_network_agents(
+                platform.platform_network_agent_create(
                     payload, network["network"]["network_id"]
                 )
                 click.secho(
@@ -995,7 +1001,8 @@ def manage_network_endpoints(
                 )
     if add_agents or remove_endpoint:
         networks_info = [
-            platform.get_network_info(net["network_id"])["data"] for net in networks
+            platform.platform_network_info(net["network_id"])["data"]
+            for net in networks
         ]
     fields = [
         ("Endpoint ID", ("agent", "agent_id")),
@@ -1019,13 +1026,13 @@ def manage_network_endpoints(
 @syntropy_platform
 def delete_network(network, yes, platform):
     """Delete a network."""
-    networks = platform.index_networks(filter=f"id|name:{network}")["data"]
+    networks = platform.platform_network_index(filter=f"id|name:'{network}'")["data"]
 
     for net in networks:
         if not yes and not confirm_deletion(net["network_name"], net["network_id"]):
             continue
 
-        platform.delete_networks(net["network_id"])
+        platform.platform_network_destroy(net["network_id"])
         click.secho(
             f"Deleted network: {net['network_name']} (id={net['network_id']}).",
             fg="green",
